==> igniteui-webcomponents-core-4.0.4.tgz: package/esm2015/lib/WebFloatingPaneResizeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSplitPaneDescriptionMetadata } from "./WebSplitPaneDescriptionMetadata";
import { WebFloatingPaneResizeEventArgsDescription } from "./WebFloatingPaneResizeEventArgsDescription";
/**
 * @hidden
 */
export let WebFloatingPaneResizeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFloatingPaneResizeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFloatingPaneResizeEventArgsDescriptionMetadata.a == null) {
                WebFloatingPaneResizeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFloatingPaneResizeEventArgsDescriptionMetadata.c(WebFloatingPaneResizeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebFloatingPaneResizeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebFloatingPaneResizeEventArgsDescriptionMetadata.a);
            WebSplitPaneDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FloatingPaneResizeEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("SourcePane", "ExportedType:WebSplitPane");
            a.item("ResizerLocation", "ExportedType:string:FloatingPaneResizeEventArgsResizerLocation");
            a.item("ResizerLocation@names", "Top;Bottom;Left;Right;TopLeft;TopRight;BottomLeft;BottomRight");
        }
        static d(a) {
            WebFloatingPaneResizeEventArgsDescriptionMetadata.b(a);
            a.ac("WebFloatingPaneResizeEventArgs", () => new WebFloatingPaneResizeEventArgsDescription());
            a.ab("WebFloatingPaneResizeEventArgs", WebFloatingPaneResizeEventArgsDescriptionMetadata.a);
        }
    }
    WebFloatingPaneResizeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFloatingPaneResizeEventArgsDescriptionMetadata, 'WebFloatingPaneResizeEventArgsDescriptionMetadata');
    WebFloatingPaneResizeEventArgsDescriptionMetadata.a = null;
    return WebFloatingPaneResizeEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebFloatingPaneResizeEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFloatingPaneResizeEventArgsDetailDescriptionMetadata } from "./WebFloatingPaneResizeEventArgsDetailDescriptionMetadata";
import { WebFloatingPaneResizeEventArgsDescription } from "./WebFloatingPaneResizeEventArgsDescription";
/**
 * @hidden
 */
export let WebFloatingPaneResizeEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebFloatingPaneResizeEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebFloatingPaneResizeEventArgsDescriptionMetadata.a == null) {
                WebFloatingPaneResizeEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebFloatingPaneResizeEventArgsDescriptionMetadata.c(WebFloatingPaneResizeEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebFloatingPaneResizeEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebFloatingPaneResizeEventArgsDescriptionMetadata.a);
            WebFloatingPaneResizeEventArgsDetailDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:FloatingPaneResizeEventArgs");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("__skipSuffix", "Boolean");
            a.item("Detail", "ExportedType:WebFloatingPaneResizeEventArgsDetail");
        }
        static d(a) {
            WebFloatingPaneResizeEventArgsDescriptionMetadata.b(a);
            a.ac("WebFloatingPaneResizeEventArgs", () => new WebFloatingPaneResizeEventArgsDescription());
            a.ab("WebFloatingPaneResizeEventArgs", WebFloatingPaneResizeEventArgsDescriptionMetadata.a);
        }
    }
    WebFloatingPaneResizeEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebFloatingPaneResizeEventArgsDescriptionMetadata, 'WebFloatingPaneResizeEventArgsDescriptionMetadata');
    WebFloatingPaneResizeEventArgsDescriptionMetadata.a = null;
    return WebFloatingPaneResizeEventArgsDescriptionMetadata;
})();
